import React, { useState } from 'react';
import deepmerge from 'deepmerge';
import { ThemeProvider } from './theme-provider';
// import { ThemeProvider } from 'styled-components';
import { defaultThemeConfig } from '.';
var getIsDarkMode = function () { return window.matchMedia("(prefers-color-scheme: dark)").matches; };
export var ColorModeContext = React.createContext();
export var useColorMode = function () {
    var colorModeState = React.useContext(ColorModeContext);
    if (!colorModeState) {
        throw new Error("[useColorMode] requires the ColorModeProvider component");
    }
    return colorModeState;
};
export var useColorModeState = function (defaultMode) {
    // eslint-disable-next-line no-nested-ternary
    var _a = useState(defaultMode || (getIsDarkMode() ? 'dark' : 'light')), mode = _a[0], setMode = _a[1];
    var toggleMode = function () {
        setMode(mode === 'dark' ? 'light' : 'dark');
    };
    return [mode, toggleMode];
};
export var ColorThemeProvider = function (_a) {
    var children = _a.children, theme = _a.theme;
    var _b = useColorModeState(theme.defaultMode), mode = _b[0], setMode = _b[1];
    var computedTheme = React.useMemo(function () { return deepmerge(defaultThemeConfig, theme || {}); }, [
        theme,
    ]);
    var currThemeColors = computedTheme.colors[mode];
    computedTheme.color = currThemeColors;
    computedTheme.activeColorMode = mode;
    return (React.createElement(ColorModeContext.Provider, { value: [
            mode,
            setMode
        ] },
        React.createElement(ThemeProvider, { theme: computedTheme, key: mode }, children)));
};
